@@ -8,13 +8,13 @@ use WWW::Shopify;
 package WWW::Shopify::Model::Order::ClientDetails;
 use parent "WWW::Shopify::Model::NestedItem";
 
-my $fields; sub fields { return $fields; } 
+my $fields; sub fields { return $fields; }
 BEGIN { $fields = {
 	"accept_language" => new WWW::Shopify::Field::String(),
 	"browser_ip" => new WWW::Shopify::Field::String::IPAddress(),
 	"session_hash" => new WWW::Shopify::Field::String("[0-9A-F]{32}"),
-	"user_agent" => new WWW::Shopify::Field::String()};
-}
+	"user_agent" => new WWW::Shopify::Field::String()
+}; }
 sub plural() { return 'properties'; }
 sub creatable { return undef; }
 sub updatable { return undef; }
