@@ -12,6 +12,7 @@ my $fields; sub fields { return $fields; }
 BEGIN { $fields = {
 	"testcase" => new WWW::Shopify::Field::Boolean(),
 	"authorization" => new WWW::Shopify::Field::String::Regex("[0-9]{4,10}"),
+	# Stripe?
 	"code" => new WWW::Shopify::Field::String(),
 	"success" => new WWW::Shopify::Field::String(),
 	"message" => new WWW::Shopify::Field::String(),
@@ -22,6 +23,17 @@ BEGIN { $fields = {
 	"reference" => new WWW::Shopify::Field::String(),
 	"order_number" => new WWW::Shopify::Field::String(),
 	"recurring" => new WWW::Shopify::Field::String(),
+	# Paypal
+	"ack" => new WWW::Shopify::Field::String::Enum(["Success", "Failure"]),
+	"timestamp" => new WWW::Shopify::Field::Date(),
+	"correlation_id" => new WWW::Shopify::Field::String(),
+	"version" => new WWW::Shopify::Field::Int(),
+	"build" => new WWW::Shopify::Field::Int(),
+	"amount" => new WWW::Shopify::Field::Money(),
+	"amount_currency" => new WWW::Shopify::Field::Currency(),
+	"avs_code" => new WWW::Shopify::Field::String(),
+	"cvv2_code" => new WWW::Shopify::Field::String(),
+	"transaction_id" => new WWW::Shopify::Field::String()
 }; }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
